from setuptools import setup

setup(name='distributions_acc',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions_acc'],
      author = 'Andrea Cruz Castillo',
      zip_safe=False)
